/**
 * $Id: FileHelper.java,v 1.3 2008/09/16 20:46:16 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 11.09.2008 by oliver (ob@oasd.de)
 */
package patterntesting.io;

import java.io.*;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.impl.LogFactoryImpl;

/**
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 11.09.2008
 * @version $Revision: 1.3 $
 */
public class FileHelper {
	
	private static Log log = LogFactoryImpl.getLog(FileHelper.class);
	
	public static File getTmpdir() {
		return new File(System.getProperty("java.io.tmpdir"));
	}
	
	public static File getTmpdir(File file) {
		return getTmpdir(file.toString());
	}
	
	public static File getTmpdir(String filename) {
		return new File(getTmpdir(), filename);
	}
	
	public static IOException betterIOException(IOException ioe, File file) {
		return betterIOException(ioe, file.getAbsolutePath());
	}
	
	/**
	 * The cause of the given IOException is ignored for the moment bcause
	 * the constructor IOException(String s, Throwable t) is not available
	 * in Java 5.
	 * 
	 * @param ioe
	 * @param filename
	 * @return
	 */
	public static IOException betterIOException(IOException ioe,
			String filename) {
		String msg = ioe.getMessage() + ": " + filename;
		Throwable cause = ioe.getCause();
		if (cause == null) {
			return new IOException(msg);
		} else {
			log.warn("cause: " + cause);
			return new IOException(msg);
		}
	}

}

/**
 * $Log: FileHelper.java,v $
 * Revision 1.3  2008/09/16 20:46:16  oboehm
 * switch to commons-logging for more flexibility
 *
 * Revision 1.2  2008/09/11 14:47:41  oboehm
 * using now only Java 5 constructor for IOException
 *
 * Revision 1.1  2008/09/11 08:13:57  oboehm
 * IOException from File methods contains now the fail
 * in the exception message
 *
 * $Source: /cvsroot/patterntesting/PatternTesting05/src/main/java/patterntesting/io/FileHelper.java,v $
 */
