/* 
 *========================================================================
 * 
 * Copyright 2004-2005 Vincent Massol & Matt Smith.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *========================================================================
 */
package patterntesting.java.runtime;

import patterntesting.plugin.aspectj.Logger;


/**
 * @author <a href="mailto:matt@ojojo.com">Matt Smith</a>
 * 
 * @version $Id: AbstractNullTest.aj,v 1.1 2007/05/19 22:33:00 oboehm Exp $
 *
 */
public abstract aspect AbstractNullTest 
{
   /**
    * Specify what is application code that should be subject to the
    * pattern test.
    * 
    * Ex: <code>pointcut applicationCode(): within(patterntesting.*)</code>
    */
   public abstract pointcut applicationCode();
   
   /**
    * Specify which code is allowed to have <code>null</code> parameters.
    */
   public abstract pointcut allowedCode();
   
   /**
    * Invalid null parameter.
    */
   pointcut invalidNullParameter() :
       execution(* *.*(*,..))
       && applicationCode()
       && !allowedCode();
   
   before() : invalidNullParameter() 
   {
      Logger logger = Logger.getInstance();
      Object[] parms = thisJoinPoint.getArgs();
      if(parms != null)
      {
	      for(int i = 0; i < parms.length; i++)
	      {
	         if(parms[i] == null)
	         {
	            logger.logPTViolation(thisJoinPoint.getSourceLocation(), getMessage());
	         }
	      }
      }
   }
   
   public abstract String getMessage();
}
