/**
 * $Id: NullPointerTrap.aj,v 1.1 2008/09/16 20:18:14 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 12.09.2008 by oliver (ob@oasd.de)
 */
package patterntesting.java.runtime;

import patterntesting.java.runtime.annotation.*;

/**
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 12.09.2008
 * @version $Revision: 1.1 $
 */
public aspect NullPointerTrap {
	
	/**
	 * Addresses all methods (or constructors) with at least one argument with should
	 * not be given as null parameter
	 */
	pointcut invalidNullParameter() :
		(execution(* *..*(*, ..)) || execution(*..new(*, ..)))
		&& !(execution(@NullArgsAllowed * *..*(*, ..))
				|| execution(@NullArgsAllowed *..new(*, ..)))
		&& !within(@NullArgsAllowed *);
	
	/**
	 * If a (null) parameter is detected something is wrong with the
	 * application code
	 */
	before() : invalidNullParameter() {
		Object[] args = thisJoinPoint.getArgs();
		if (args != null) {
			for(int i = 0; i < args.length; i++) {
				if (args[i] == null) {
					throw new AssertionError("arg" + i + " is null");
				}
			}
		}
	}
	
	
	
	/**
	 * To check all non void methods if returns a null value we first define
	 * the pointcut here.
	 */
	private pointcut nonVoidMethods() :
		execution(Object+ *..*(..))
		&& !(execution(@MayReturnNull Object+ *..*(..)))
		&& !within(@MayReturnNull *);
	
	/**
	 * A 'null' as return value is often an indication that something is wrong
	 * (otherwise an exception should be thrown)
	 */
    after() returning(Object returned) : nonVoidMethods() {
        if (returned == null) {
            throw new AssertionError(thisJoinPoint.getSignature() 
                    + " returns (null)!");
        }
    }

}

/**
 * $Log: NullPointerTrap.aj,v $
 * Revision 1.1  2008/09/16 20:18:14  oboehm
 * concrete StackTraceAspect and SystemAspect added
 * (can be disabled via annotations)
 *
 * $Source: /cvsroot/patterntesting/PatternTesting05/src/main/aspect/patterntesting/java/runtime/NullPointerTrap.aj,v $
 */
